@@ -9,23 +9,22 @@
 #' filing information. The function imports annual filings downloaded 
 #' via \link[edgar]{getFilings} function; otherwise, it downloads the filings which are 
 #' not already been downloaded. It then reads, cleans, and parse the required section 
-#' from the filings. It creates a new directory with the name "MD&A section text" 
+#' from the filings. It creates a new directory with the name "edgar_MgmtDisc" 
 #' in the current working directory to save scrapped "Item 7" sections in text format. 
 #' It considers "10-K", "10-K405", "10KSB", and "10KSB40" form types as annual statements. 
-#' According to SEC EDGAR's guidelines a user also needs to declare user agent. 
-#' 
+#' User must follow the US SEC's fair access policy, i.e. download only what you 
+#' need and limit your request rates, see \url{https://www.sec.gov/os/accessing-edgar-data}.
 #'   
-#' @usage getMgmtDisc(cik.no, filing.year, useragent)
+#' @usage getMgmtDisc(cik.no, filing.year)
 #' 
 #' @param cik.no vector of firm CIK numbers in integer format. Suppress leading 
 #' zeroes from CIKs.
 #' 
 #' @param filing.year vector of four digit numeric year
 #' 
-#' @param useragent Should be in the form of "Your Name Contact@domain.com"
 #' 
 #' @return Function saves scrapped "Item 7" section from annual filings in 
-#' "MD&A section text" directory present in the working directory. 
+#' "edgar_MgmtDisc" directory present in the working directory. 
 #' The output dataframe contains information on CIK number, company name, 
 #' date of filing, and accession number. For a successful extraction of M&A section, 
 #' 'extract.status' column returns 1, other return 0 for failed extraction. 
@@ -33,43 +32,19 @@
 #' @examples
 #' \dontrun{
 #' 
-#' output <- getMgmtDisc(cik.no = c(1000180, 38079), filing.year = 2005, useragent)
+#' output <- getMgmtDisc(cik.no = c(1000180, 38079), filing.year = 2005)
 #' 
 #' ## saves scrapped "Item 7" section from 10-K filings for CIKs in 
-#' "MD&A section text" directory present in the working directory. 
+#' "edgar_MgmtDisc" directory present in the working directory. 
 #' Also, it provides filing information in the output datframe.
 #' 
 #' output <- getMgmtDisc(cik.no = c(1000180, 38079), 
-#'                       filing.year = c(2005, 2006), useragent)
+#'                       filing.year = c(2005, 2006))
 #'}
 
-getMgmtDisc <- function(cik.no, filing.year, useragent="" ) {
-    
+getMgmtDisc <- function(cik.no, filing.year) {
   
-  ### Check for valid user agent
-  if(useragent != ""){
-    # Check user agent
-    bb <- any(grepl( "lonare.gunratan@gmail.com|glonare@uncc.edu|bharatspatil@gmail.com",
-                     useragent, ignore.case = T))
-    
-    if(bb == TRUE){
-      
-      cat("Please provide a valid User Agent. 
-      Visit https://www.sec.gov/os/accessing-edgar-data 
-      for more information")
-      return()
-    }
-    
-  }else{
-    
-    cat("Please provide a valid User Agent. 
-      Visit https://www.sec.gov/os/accessing-edgar-data 
-      for more information")
-    return()
-  }
-  
-  
-    f.type <- c("10-K", "10-K405","10KSB", "10KSB40")
+    f.type <- c("10-K", "10-K405","10KSB", "10-KSB", "10KSB40")
     # 10-K, 10-K405, 10-KSB, 10-KT, 10KSB, 10KSB40, and 10KT405 filings in the EDGAR database
 
     # Check the year validity
@@ -79,7 +54,7 @@ getMgmtDisc <- function(cik.no, filing.year, useragent="" ) {
     }
     
     output <- getFilings(cik.no = cik.no, form.type = f.type , filing.year, 
-						 quarter = c(1, 2, 3, 4), downl.permit = "y", useragent)
+						 quarter = c(1, 2, 3, 4), downl.permit = "y")
     
     if (is.null(output)){
       cat("No annual statements found for given CIK(s) and year(s).")
@@ -104,7 +79,7 @@ getMgmtDisc <- function(cik.no, filing.year, useragent="" ) {
       return(text)
     }
 
-    new.dir <- paste0("MD&A section text")
+    new.dir <- paste0("edgar_MgmtDisc")
     dir.create(new.dir)
     
     output$extract.status <- 0
@@ -120,7 +95,7 @@ getMgmtDisc <- function(cik.no, filing.year, useragent="" ) {
         date.filed <- output$date.filed[i]
         accession.number <- output$accession.number[i]
         
-        dest.filename <- paste0("Edgar filings_full text/Form ", f.type, 
+        dest.filename <- paste0("edgar_Filings/Form ", f.type, 
                                 "/", cik, "/", cik, "_", f.type, "_", 
                                 date.filed, "_", accession.number, ".txt")
 								
@@ -145,17 +120,17 @@ getMgmtDisc <- function(cik.no, filing.year, useragent="" ) {
         })
         
         # See if 10-K is in XLBR or old text format
-        if (any(grepl(pattern = "<xml>|<type>xml|<html>|10k.htm", filing.text, ignore.case = T))) {
+        if (any(grepl(pattern = "<xml>|<type>xml|<html>|10k.htm|<XBRL>", filing.text, ignore.case = T))) {
             
-            doc <- XML::htmlParse(filing.text, asText = TRUE, useInternalNodes = TRUE, addFinalizer = FALSE)
-            
-            f.text <- XML::xpathSApply(doc, "//text()[not(ancestor::script)][not(ancestor::style)][not(ancestor::noscript)][not(ancestor::form)]", 
-                XML::xmlValue)
-            
-            f.text <- iconv(f.text, "latin1", "ASCII", sub = " ")
-			
-			      ## Free up htmlParse document to avoid memory leakage, this calls C function
-            #.Call('RS_XML_forceFreeDoc', doc, package= 'XML')
+          doc <- XML::htmlParse(filing.text, asText = TRUE, useInternalNodes = TRUE, addFinalizer = FALSE)
+                      
+          f.text <- XML::xpathSApply(doc, "//text()[not(ancestor::script)][not(ancestor::style)][not(ancestor::noscript)][not(ancestor::form)]", 
+          XML::xmlValue)
+                      
+          f.text <- iconv(f.text, "latin1", "ASCII", sub = " ")
+          			
+          ## Free up htmlParse document to avoid memory leakage, this calls C function
+          #.Call('RS_XML_forceFreeDoc', doc, package= 'XML')
             
         } else {
             f.text <- filing.text
@@ -266,7 +241,7 @@ getMgmtDisc <- function(cik.no, filing.year, useragent="" ) {
     output$filing.year <- NULL
     names(output)[names(output) == 'status'] <- 'downld.status'
     
-    cat("MD&A section texts are stored in 'MD&A section text' directory.")
+    cat("MD&A section texts are stored in 'edgar_MgmtDisc' directory.")
     
     return(output)
 }
